"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai = __importStar(require("chai"));
const chai_1 = require("chai");
const errors_1 = require("./errors");
const chaiAsPromised = require("chai-as-promised");
const dirtyChai = require("dirty-chai");
chai.use(chaiAsPromised);
chai.use(dirtyChai);
const message = 'Sample message';
const keyId = 'keyid_1';
function throwKeystoreError() {
    throw new errors_1.KeystoreError(message);
}
function throwPrivateKeyNotFoundError() {
    throw new errors_1.PrivateKeyNotFoundError(keyId);
}
function throwCertificateNotFoundError() {
    throw new errors_1.CertificateNotFoundError(keyId);
}
function throwPrivateKeyPassphraseNotFoundError() {
    throw new errors_1.PrivateKeyPassphraseNotFoundError(keyId);
}
describe('errors', () => {
    describe('KeystoreError', () => {
        it('a new instance should have the appropriate properties', () => {
            try {
                throwKeystoreError();
            }
            catch (err) {
                chai_1.expect(err.name).to.equal('KeystoreError');
                chai_1.expect(err instanceof errors_1.KeystoreError).to.be.true();
                chai_1.expect(err instanceof Error).to.be.true();
                chai_1.expect(require('util').isError(err)).to.be.true();
                chai_1.expect(err.stack).to.exist();
                chai_1.expect(err.toString()).to.equal(`KeystoreError: ${message}`);
                chai_1.expect(err.stack.split('\n')[0]).to.equal(`KeystoreError: ${message}`);
                chai_1.expect(err.stack.split('\n')[1].indexOf('throwKeystoreError')).to.equal(7);
            }
        });
    });
    describe('PrivateKeyNotFoundError', () => {
        it('a new instance should have the appropriate properties', () => {
            try {
                throwPrivateKeyNotFoundError();
            }
            catch (err) {
                chai_1.expect(err.name).to.equal('PrivateKeyNotFoundError');
                chai_1.expect(err instanceof errors_1.PrivateKeyNotFoundError).to.be.true();
                chai_1.expect(err instanceof errors_1.KeystoreError).to.be.true();
                chai_1.expect(err instanceof Error).to.be.true();
                chai_1.expect(require('util').isError(err)).to.be.true();
                chai_1.expect(err.stack).to.exist();
                chai_1.expect(err.toString()).to.equal(`PrivateKeyNotFoundError: private key not found, key id: ${keyId}`);
                chai_1.expect(err.keyId).to.equal(keyId);
                chai_1.expect(err.message).to.equal(`private key not found, key id: ${keyId}`);
                chai_1.expect(err.stack.split('\n')[0])
                    .to
                    .equal(`PrivateKeyNotFoundError: private key not found, key id: ${keyId}`);
                chai_1.expect(err.stack.split('\n')[1].indexOf('throwPrivateKeyNotFoundError')).to.equal(7);
            }
        });
    });
    describe('CertificateNotFoundError', () => {
        it('a new instance should have the appropriate properties', () => {
            try {
                throwCertificateNotFoundError();
            }
            catch (err) {
                chai_1.expect(err.name).to.equal('CertificateNotFoundError');
                chai_1.expect(err instanceof errors_1.CertificateNotFoundError).to.be.true();
                chai_1.expect(err instanceof errors_1.KeystoreError).to.be.true();
                chai_1.expect(err instanceof Error).to.be.true();
                chai_1.expect(require('util').isError(err)).to.be.true();
                chai_1.expect(err.stack).to.exist();
                chai_1.expect(err.toString()).to.equal(`CertificateNotFoundError: certificate not found, key id: ${keyId}`);
                chai_1.expect(err.keyId).to.equal(keyId);
                chai_1.expect(err.message).to.equal(`certificate not found, key id: ${keyId}`);
                chai_1.expect(err.stack.split('\n')[0])
                    .to
                    .equal(`CertificateNotFoundError: certificate not found, key id: ${keyId}`);
                chai_1.expect(err.stack.split('\n')[1].indexOf('throwCertificateNotFoundError')).to.equal(7);
            }
        });
    });
    describe('PrivateKeyPassphraseNotFoundError', () => {
        it('a new instance should have the appropriate properties', () => {
            try {
                throwPrivateKeyPassphraseNotFoundError();
            }
            catch (err) {
                chai_1.expect(err.name).to.equal('PrivateKeyPassphraseNotFoundError');
                chai_1.expect(err instanceof errors_1.PrivateKeyPassphraseNotFoundError).to.be.true();
                chai_1.expect(err instanceof errors_1.KeystoreError).to.be.true();
                chai_1.expect(err instanceof Error).to.be.true();
                chai_1.expect(require('util').isError(err)).to.be.true();
                chai_1.expect(err.stack).to.exist();
                chai_1.expect(err.toString())
                    .to
                    .equal(`PrivateKeyPassphraseNotFoundError: private key passphrase not found, key id: ${keyId}`);
                chai_1.expect(err.keyId).to.equal(keyId);
                chai_1.expect(err.message).to.equal(`private key passphrase not found, key id: ${keyId}`);
                chai_1.expect(err.stack.split('\n')[0])
                    .to
                    .equal(`PrivateKeyPassphraseNotFoundError: private key passphrase not found, key id: ${keyId}`);
                chai_1.expect(err.stack.split('\n')[1].indexOf('throwPrivateKeyPassphraseNotFoundError')).to.equal(7);
            }
        });
    });
});
//# sourceMappingURL=errors.spec.js.map