"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai = __importStar(require("chai"));
const chai_1 = require("chai");
const path = __importStar(require("path"));
const reader_1 = require("./reader");
const chaiAsPromised = require("chai-as-promised");
const dirtyChai = require("dirty-chai");
chai.use(chaiAsPromised);
chai.use(dirtyChai);
describe('keystoreReaderFs', () => {
    const keys = new Map();
    it('Should read all RSA keys in a directory', async () => {
        const baseDir = path.join(__dirname, '/../test/keys_ca/rsa');
        const keystoreReaderFs = new reader_1.KeystoreReaderFs(baseDir);
        const newKeys = await keystoreReaderFs.readKeys(keys);
        newKeys.forEach(key => {
            chai_1.expect(key).has.property('timestamp');
            chai_1.expect(key).has.property('cert');
            chai_1.expect(key).has.property('privKey');
            chai_1.expect(key).has.property('pubkeyJwk');
            chai_1.expect(key.pubkeyJwk).has.property('kid');
            chai_1.expect(key.pubkeyJwk.kty).to.equal('RSA');
            chai_1.expect(key.pubkeyJwk).has.property('n');
            chai_1.expect(key.pubkeyJwk).has.property('e');
            chai_1.expect(key.pubkeyJwk.alg).to.equal('RS256');
            chai_1.expect(key.pubkeyJwk.use).to.equal('sig');
            chai_1.expect(key.pubkeyJwk).has.property('x5c');
        });
        chai_1.expect(newKeys.has('1')).to.be.true();
        chai_1.expect(newKeys.has('2')).to.be.true();
        chai_1.expect(newKeys.has('3')).to.be.true();
        chai_1.expect(newKeys.size).to.equal(3);
    });
    it('Should read all ECDSA keys in a directory', async () => {
        const baseDir = path.join(__dirname, '/../test/keys_ca/ecdsa');
        const keystoreReaderFs = new reader_1.KeystoreReaderFs(baseDir);
        const newKeys = await keystoreReaderFs.readKeys(keys);
        newKeys.forEach(key => {
            chai_1.expect(key).has.property('timestamp');
            chai_1.expect(key).has.property('cert');
            chai_1.expect(key).has.property('privKey');
            chai_1.expect(key).has.property('pubkeyJwk');
            chai_1.expect(key.pubkeyJwk).has.property('kid');
            chai_1.expect(key.pubkeyJwk.kty).to.equal('EC');
            chai_1.expect(key.pubkeyJwk.crv).to.equal('P-256');
            chai_1.expect(key.pubkeyJwk).has.property('x');
            chai_1.expect(key.pubkeyJwk).has.property('y');
            chai_1.expect(key.pubkeyJwk.alg).to.equal('ES256');
            chai_1.expect(key.pubkeyJwk.use).to.equal('sig');
            chai_1.expect(key.pubkeyJwk).has.property('x5c');
        });
        chai_1.expect(newKeys.has('1')).to.be.true();
        chai_1.expect(newKeys.has('2')).to.be.true();
        chai_1.expect(newKeys.has('3')).to.be.true();
        chai_1.expect(newKeys.size).to.equal(3);
    });
    it('Should fail if a wrong directory is passed', function () {
        const fakeBaseDir = path.join(__dirname, '/../test/keys_ca/_fake_');
        chai_1.expect(() => new reader_1.KeystoreReaderFs(fakeBaseDir)).to.throw(Error, /ENOENT/);
    });
});
//# sourceMappingURL=reader.spec.js.map