import { IDebugger } from 'debug';
import { KeyAndCert, KeystoreReader } from '../contracts';
export declare class KeystoreReaderFs implements KeystoreReader {
    protected debug: IDebugger;
    protected baseDir: string;
    protected caCert: string;
    protected algMap: {
        [key: string]: string;
    };
    /**
     * Creates a keystore reader function
     *
     * @param  baseDir The keystore base directory
     * @param  debugNamePrefix Name prefix used for the debug module
     */
    constructor(baseDir: string, debugNamePrefix?: string);
    /**
     * Handles the specified key id, i.e. returns a promise that loads the appropriate
     * private key and certificate from files
     *
     * @param {Map.<KeyAndCert>} newKeys A Map of key and cert data objects
     * @param {string} keyId Key ID
     * @return {Promise} A Promise that is resolved when the private and key a certificate for
     *                   the given keyId is loaded into the newKeys Object
     */
    protected handleKeyId(newKeys: Map<string, KeyAndCert>, keyId: string): Promise<void>;
    /**
     * Creates s combined set of promises that are used for verifying and reading certs and private keys
     *
     * @param  {type} newKeys {Map.<KeyAndCert>} newKeys A Map of key and cert data objects
     * @param  {type} keyId Key ID
     * @return {Promise} A promise which is resolved when both the certificate and the
     *                   private key is loaded for the given key id
     */
    readKeyAndCert(newKeys: Map<string, KeyAndCert>, keyId: string): Promise<void>;
    /**
     * Verifies the given certificate if it is certified with the KKSZB CA
     *
     * @param {string} keyId Key id
     * @param {string} certPem The certificate in PEM format
     * @return {Promise} A promise which is resolved if the given certificate is trusted
     */
    verifyCertAsync(keyId: string, certPem: string): Promise<string>;
    /**
     * Reads all keys and certs from the keystore base directory
     *
     * @param {Object} keys A map containing the currently loaded keys
     * @return {Promise.<Map.<KeyAndCert>, Error>} Promise to an object containing the already existing and loaded keys
     */
    readKeys(keys: Map<string, KeyAndCert>): Promise<Map<string, KeyAndCert>>;
}
